@@ -18,9 +18,8 @@ G_BEGIN_DECLS
 
 #define GS_TYPE_REPOS_DIALOG (gs_repos_dialog_get_type ())
 
-G_DECLARE_FINAL_TYPE (GsReposDialog, gs_repos_dialog, GS, REPOS_DIALOG, AdwWindow)
+G_DECLARE_FINAL_TYPE (GsReposDialog, gs_repos_dialog, GS, REPOS_DIALOG, AdwDialog)
 
-GtkWidget	*gs_repos_dialog_new		(GtkWindow	*parent,
-						 GsPluginLoader	*plugin_loader);
+GtkWidget	*gs_repos_dialog_new		(GsPluginLoader	*plugin_loader);
 
 G_END_DECLS
